## Installation

Before installing openstack_cli, it is recommended to create a virtual environment to isolate it from your system Python installation. This can help to avoid conflicts with other packages and make it easier to manage dependencies. To create a virtual environment, run the following commands:

```bash
python -m venv myenv
source myenv/bin/activate
```

Replace `myenv` with the desired name of your virtual environment.
After creating the virtual environment, you can then go to next step:

To install openstack_cli from PyPI, you will need to have Python and pip installed on your system. If you don't have them, you can download them from [python.org](https://www.python.org/) and [pip.pypa.io](https://pip.pypa.io/en/stable/installation/).

Once you have Python and pip installed, run the following command in your terminal or command prompt:

```bash
pip install openstack_cli
```

This will download and install `openstack_cli` and its dependencies.

After installation, you can run `openstack --version` by typing the following command in your
terminal or command prompt:

```bash
openstack --version
```
